/***********************************************************************
 *
 * SPACE TRADER 1.2.0
 *
 * SpecialEncounter.c
 *
 * Copyright (C) 2000-2002 Pieter Spronck, All Rights Reserved
 *
 * Additional coding by Sam Anderson (rulez2@home.com)
 * Additional coding by Samuel Goldstein (palm@fogbound.net)
 *
 * Some code of Matt Lee's Dope Wars program has been used.
 *
 * This particular file by SjG, but based on all the abovementioned code.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 * You can contact the author at space_trader@hotmail.com
 *
 * For those who are familiar with the classic game Elite: many of the
 * ideas in Space Trader are heavily inspired by Elite.
 *
 **********************************************************************/

// *************************************************************************
// SpecialEncounter.c - Functions in this module:
// -------------------------------------------------------------------- 
//
// Boolean VeryRareEncounterFormHandleEvent ( EventPtr eventP ) 
//
// -------------------------------------------------------------------- 
// Static Local Functions
// --------------------------------------------------------------------
// Boolean ExecuteAttack( SHIP* Attacker, SHIP* Defender, Boolean Flees, Boolean CommanderUnderAttack )
// void ShowShip( SHIP* Sh, int offset )
// void EncounterDisplayShips( void )
// void EncounterDisplayNextAction( Boolean FirstDisplay )
// void EncounterButtons( void )
//
// -------------------------------------------------------------------------
// Modifications:
// mm/dd/yy - description - author
// 06/30/01 - Police Encounter text changed - SRA
// -------------------------------------------------------------------------
//
// *************************************************************************

#include "external.h"


// *************************************************************************
// Buttons on the encounter screen
// *************************************************************************
static void RareEncounterButtons( void )
{
	FormPtr frmP;

	frmP = FrmGetActiveForm();


	if (!TextualEncounters)
	{
		FrmHideObject( frmP, FrmGetObjectIndex( frmP, VeryRareEncounterYouLabel ) );
		FrmHideObject( frmP, FrmGetObjectIndex( frmP, VeryRareEncounterOpponentLabel ) );
	}
	if (EncounterType == MARIECELESTEENCOUNTER)
	{
		FrmHideObject( frmP, FrmGetObjectIndex( frmP, VeryRareEncounterHailButton ) );
		FrmHideObject( frmP, FrmGetObjectIndex( frmP, VeryRareEncounterDrinkButton ) );
		FrmShowObject( frmP, FrmGetObjectIndex( frmP, VeryRareEncounterBoardButton ) );
	}
	else if (EncounterType == CAPTAINAHABENCOUNTER ||
			 EncounterType == CAPTAINHUIEENCOUNTER ||
			 EncounterType == CAPTAINCONRADENCOUNTER)
	{
		FrmShowObject( frmP, FrmGetObjectIndex( frmP, VeryRareEncounterHailButton ) );
		FrmHideObject( frmP, FrmGetObjectIndex( frmP, VeryRareEncounterDrinkButton ) );
		FrmHideObject( frmP, FrmGetObjectIndex( frmP, VeryRareEncounterBoardButton ) );
	}
	else if (EncounterType == BOTTLEOLDENCOUNTER ||
	         EncounterType == BOTTLEGOODENCOUNTER)
	{
		FrmHideObject( frmP, FrmGetObjectIndex( frmP, VeryRareEncounterHailButton ) );
		FrmShowObject( frmP, FrmGetObjectIndex( frmP, VeryRareEncounterDrinkButton ) );
		FrmHideObject( frmP, FrmGetObjectIndex( frmP, VeryRareEncounterBoardButton ) );
	}


}

// *************************************************************************
// Display on the encounter screen what the next action will be
// *************************************************************************
static void RareEncounterDisplayNextAction( Boolean FirstDisplay )
{
	if (EncounterType == MARIECELESTEENCOUNTER)
	{
		DrawChars( "The Marie Celeste appears to", 6, 106 );
		DrawChars( "be completely abandoned.", 6, 119 );
	}
	else if (EncounterType == CAPTAINAHABENCOUNTER ||
			 EncounterType == CAPTAINHUIEENCOUNTER ||
			 EncounterType == CAPTAINCONRADENCOUNTER)
	{
		DrawChars( "The Captain requests a brief", 6, 106 );
		DrawChars( "meeting with you.", 6, 119 );
	}
	else if (EncounterType == BOTTLEOLDENCOUNTER ||
	         EncounterType == BOTTLEGOODENCOUNTER)
	{
		DrawChars( "It appears to be a rare bottle", 6, 106);
		DrawChars( "of Captain Marmoset's Skill Tonic!", 6, 119);
    }
}

// *************************************************************************
// Display on the encounter screen the ships (and also wipe it)
// *************************************************************************
static void RareEncounterDisplayShips( void )
{
	EraseRectangle( 0, 32, 156, 100 );

	ShowShip( &Ship, 6 );
	ShowShip( &Opponent, (TextualEncounters ? 84 : 80) );
}



// *************************************************************************
// Encounter screen Event Handler
// *************************************************************************
Boolean VeryRareEncounterFormHandleEvent ( EventPtr eventP )
{
    Boolean handled = false;
	FormPtr frmP;
 	int d, i;
	int objindex;
	ControlPtr cp;
	Boolean RedrawButtons = false;

	switch (eventP->eType) 
	{
		case frmOpenEvent:
			frmP = FrmGetActiveForm();
			
			RareEncounterButtons();
			
			FrmDrawForm( frmP );

			RareEncounterDisplayShips();
			RareEncounterDisplayNextAction( true );
			
			StrCopy( SBuf, "At " );
			SBufMultiples( Clicks, "click" );
			StrCat( SBuf, " from " );
			StrCat( SBuf, SolarSystemName[SolarSystem[WarpSystem].NameIndex] );
			StrCat( SBuf, ", you" );
			DrawChars( SBuf, 6, 75 );			

			StrCopy( SBuf, "encounter " );
			switch (EncounterType)
				{
				case MARIECELESTEENCOUNTER:
					StrCat(SBuf,"a mysterious ship");
					break;
				case CAPTAINAHABENCOUNTER:
					StrCat(SBuf, "the famous Captain Ahab");
					break;
				case CAPTAINCONRADENCOUNTER:
					StrCat(SBuf, "Captain Conrad");
					break;
				case CAPTAINHUIEENCOUNTER:
					StrCat(SBuf, "Captain Huie");
					break;
				case BOTTLEOLDENCOUNTER:
				case BOTTLEGOODENCOUNTER:
					StrCat(SBuf, "a floating bottle.");
					break;
				}
			StrCat( SBuf, "." );
			
			DrawChars( SBuf, 6, 88 );			

			d = sqrt( Ship.Tribbles/250 );
			for (i=0; i<d; ++i)
			{
				objindex = FrmGetObjectIndex( frmP, EncounterTribble0Button +
					GetRandom( TRIBBLESONSCREEN ) );
				cp = (ControlPtr)FrmGetObjectPtr( frmP, objindex );
				CtlShowControl( cp );
			}

			handled = true;
			break;
			
		case ctlSelectEvent:
			if (eventP->data.ctlSelect.controlID >= EncounterTribble0Button &&
				eventP->data.ctlSelect.controlID < EncounterTribble0Button + TRIBBLESONSCREEN)
			{
				if (RedrawButtons)
					RareEncounterButtons();
					
				FrmAlert( SqueekAlert );
				handled = true;
				break;
			}

			else if (eventP->data.ctlSelect.controlID == VeryRareEncounterIgnoreButton) // Ignore. 
			{			
				if (RedrawButtons)
					RareEncounterButtons();
			}					
			else if (eventP->data.ctlSelect.controlID == VeryRareEncounterHailButton) // Hail Captain
			{
				if (RedrawButtons)
					RareEncounterButtons();
				if (EncounterType == CAPTAINAHABENCOUNTER)
				{
					// Trade a reflective shield for skill points in piloting?
					if (FrmAlert( EngageCaptainAhabAlert) == EngageCaptainAhabYesTradeShield)
					{
						// remove the last reflective shield
						i=MAXSHIELD - 1;
						while (i > 0)
						{
							if (Ship.Shield[i] == REFLECTIVESHIELD)
							{
								Ship.Shield[i] = -1;
								i = -1;
							}
							i--;
						}
						// add points to piloting skill
						// two points if you're on beginner-normal, one otherwise
						if (Difficulty < HARD)
							COMMANDER.Pilot += 2;
						else
							COMMANDER.Pilot += 1;
							
						if (COMMANDER.Pilot > MAXSKILL)
						{
							COMMANDER.Pilot = MAXSKILL;
						}
						FrmAlert( TrainingCompletedAlert );
					}
				}
				else if (EncounterType == CAPTAINCONRADENCOUNTER)
				{
					// Trade a military laser for skill points in engineering?
					if (FrmAlert( EngageCaptainConradAlert) == EngageCaptainConradYesTradeLaser)
					{
						// remove the last military laser
						i=MAXWEAPON - 1;
						while (i>0)
						{
							if (Ship.Weapon[i] == MILITARYLASERWEAPON)
							{
								Ship.Weapon[i] = -1;
								i = -1;
							}
							i--;
						}
						// add points to engineering skill
						// two points if you're on beginner-normal, one otherwise
						if (Difficulty < HARD)
							COMMANDER.Engineer += 2;
						else
							COMMANDER.Engineer += 1;
							
						if (COMMANDER.Engineer > MAXSKILL)
						{
							COMMANDER.Engineer = MAXSKILL;
						}
						FrmAlert( TrainingCompletedAlert );
					}
				}
				else if (EncounterType == CAPTAINHUIEENCOUNTER)
				{
					// Trade a military laser for skill points in trading?
					if (FrmAlert( EngageCaptainHuieAlert) == EngageCaptainHuieYesTradeLaser)
					{
						// remove the last military laser
						i=MAXWEAPON - 1;
						while (i>0)
						{
							if (Ship.Weapon[i] == MILITARYLASERWEAPON)
							{
								Ship.Weapon[i] = -1;
								i = -1;
							}
							i--;
						}
						// add points to trading skill
						// two points if you're on beginner-normal, one otherwise
						if (Difficulty < HARD)
							COMMANDER.Trader += 2;
						else
							COMMANDER.Trader += 1;
							
						if (COMMANDER.Trader > MAXSKILL)
						{
							COMMANDER.Trader = MAXSKILL;
						}
						RecalculateBuyPrices();
						FrmAlert( TrainingCompletedAlert );
					}
				}
			}
			else if (eventP->data.ctlSelect.controlID == VeryRareEncounterBoardButton) // Board Marie Celeste
			{
				if (RedrawButtons)
					RareEncounterButtons();
				if (EncounterType == MARIECELESTEENCOUNTER)
				{
					// take the cargo of the Marie Celeste?
					if (FrmAlert( EngageMarieAlert ) == EngageMarieYesTakeCargo)
					{
						FrmPopupForm( PlunderForm );
					}
				}
			}		
			else if (eventP->data.ctlSelect.controlID == VeryRareEncounterDrinkButton) // Drink Tonic?
			{
				if (RedrawButtons)
					RareEncounterButtons();
				if (EncounterType == BOTTLEGOODENCOUNTER)
				{
					// Quaff the good bottle of Skill Tonic?
					if (FrmAlert( EngageGoodBottleAlert ) == EngageGoodBottleYesDrinkIt)
					{
						// two points if you're on beginner-normal, one otherwise
						IncreaseRandomSkill();
						if (Difficulty < HARD)
							IncreaseRandomSkill();
						FrmAlert( GoodDrinkAlert );
					}
				}
				else if (EncounterType == BOTTLEOLDENCOUNTER)
				{
					// Quaff the out of date bottle of Skill Tonic?
					if (FrmAlert( EngageOldBottleAlert ) == EngageOldBottleYesDrinkIt)
					{
						TonicTweakRandomSkill();
						FrmAlert( StrangeDrinkAlert );
					}
				}

			}		
	
			Travel();
			handled = true;
			break;
				
		default:
			break;
	}
	
	return handled;
}


